@@ -24,10 +24,8 @@ from dataiter.vector import Vector # noqa
 from dataiter.data_frame import DataFrame # noqa
 from dataiter.data_frame import DataFrameColumn # noqa
 from dataiter.list_of_dicts import ListOfDicts # noqa
-from dataiter.list_of_dicts import ObsoleteError # noqa
-from dataiter.list_of_dicts import ObsoleteListOfDicts # noqa
 
-__version__ = "0.13"
+__version__ = "0.14"
 
 DEFAULT_PEEK_ELEMENTS = 10
 DEFAULT_PEEK_ITEMS = 3
